- image
path or SpatRaster
- otb
output of link2GI::linkOTB()
- spatialr
integer. Spatial radius of the neighborhood
- ranger
range radius defining the radius (expressed in radiometry unit)
in the multispectral space
- thresh
algorithm iterative scheme will stop if mean-shift vector is
below this threshold or if iteration number reached maximum number of iterations
- maxiter
integer. Algorithm iterative scheme will stop if convergence hasn’t been
reached after the maximum number of iterations
- minsize
integer. Minimum size of a region (in pixel unit) in segmentation. Smaller
clusters will be merged to the neighboring cluster with the closest radiometry.
If set to 0 no pruning is done
- mode
processing mode, either 'vector' or 'raster'. See details
- vector_neighbor
logical. If FALSE (the default) a 4-neighborhood connectivity
is activated. If TRUE, a 8-neighborhood connectivity is used
- vector_stitch
logical. If TRUE (the default), scans polygons on each side
of tiles and stitch polygons which connect by more than one pixel
- vector_minsize
integer. Objects whose size in pixels is below the minimum
object size will be ignored during vectorization
- vector_simplify
simplify polygons according to a given tolerance (in pixel).
This option allows reducing the size of the output file or database.
- vector_tilesize
integer. User defined tiles size for tile-based segmentation.
Optimal tile size is selected according to available RAM if NULL
- mask
an optional raster used for masking the segmentation. Only pixels
whose mask is strictly positive will be segmented